lilypondfiletools.LilyPondFile
==============================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.format

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.default_paper_size

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.file_initial_system_comments

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.file_initial_system_includes

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.file_initial_user_comments

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.file_initial_user_includes

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.global_staff_size

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.append

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.count

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.extend

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.index

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.insert

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.pop

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.remove

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.reverse

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.sort

   .. note:: Inherited from `__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__add__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__contains__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__delitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__delslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__eq__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__ge__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__getitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__getslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__gt__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__iadd__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__imul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__iter__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__le__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__len__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__lt__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__mul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__ne__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__repr__

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__reversed__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__rmul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__setitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__setslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__str__

   .. note:: Inherited from `__builtin__.object`
